@@ -19,6 +19,7 @@ from nordea_analytics.nalib.util import (
     convert_to_float_if_float,
     convert_to_variable_string,
     get_config,
+    get_keyfigure_key,
 )
 from nordea_analytics.nalib.value_retriever import ValueRetriever
 
@@ -87,7 +88,13 @@ class BondKeyFigureAdvancedCalculator(ValueRetriever):
         ]
         self.symbols = [symbols] if type(symbols) == str else symbols
         self.calc_date = calc_date
-
+        self.key_figures_original: Union[
+            List[str],
+            List[CalculatedBondKeyFigureName],
+            List[Union[str, CalculatedBondKeyFigureName]],
+        ] = (
+            keyfigures if isinstance(keyfigures, list) else [keyfigures]
+        )
         _curves: Union[List[Union[str, ValueError]], None]
         if isinstance(curves, list):
             _curves = [convert_to_variable_string(curve, CurveName) for curve in curves]
@@ -230,6 +237,18 @@ class BondKeyFigureAdvancedCalculator(ValueRetriever):
                         _data_dict[
                             CalculatedBondKeyFigureName(key_figure).name
                         ] = cashflow_dict
+                    elif key_figure == "vegamatrix":
+                        vega_dict = {
+                            vega_list["key"]: vega_list["value"]
+                            for vega_list in curve_data["vega_points"]
+                        }
+                        _data_dict[
+                            get_keyfigure_key(
+                                key_figure,
+                                self.key_figures_original,
+                                CalculatedBondKeyFigureName.__name__,
+                            )
+                        ] = vega_dict
                     else:
                         _data_dict[
                             CalculatedBondKeyFigureName(key_figure).name
