@@ -8,8 +8,6 @@ from nordea_analytics.nalib.data_retrieval_client import (
     DataRetrievalServiceClient,
 )
 from nordea_analytics.nalib.util import (
-    check_json_response,
-    check_json_response_error,
     convert_to_variable_string,
     get_config,
 )
@@ -49,9 +47,6 @@ class YieldForecast(ValueRetriever):
         json_response = self.get_response(self.request)
         json_response = json_response[config["results"]["yield_forecast"]]
 
-        output_found = check_json_response(json_response)
-        check_json_response_error(output_found)
-
         return json_response
 
     @property
